@@ -1,4 +1,4 @@
-GOOF----LE-4-2.0W      ]  4  hE
+GOOF----LE-8-2.0W      ]  4  hE
       ] g  guile	 	g  define-module*	 	 	g  ice-9	g  ftw	 		g  filenameS	
 f  
 ice-9/ftw.scm	g  importsS	g  match	
@@ -12,7 +12,7 @@ visited?-proc	=g  getuid	>g  getgid	?g  
 stat:perms	@g  stat:uid	Ag  stat:gid	Bg  stat-dir-readable?-proc	Cg  memq	Dg  depth	Eg  directory-processed	Fg  	directory	Gg  
 nftw-style	Hg  
 stale-symlink	Ig  symlink	Jg  physical	Kg  catch	LK 	MK 	Ng  lstat	Og  	stat:type	Pg  stat	Qg  directory-not-readable	Rg  regular	Sg  invalid-stat	Tg  stat&flag-proc	Ug  clean	Vg  	hash-size	Wg  throw	Xg  ftw-early-exit	Yg  for-each	Zg  getcwd	[g  mount	\g  chdir	]g  nftw-early-exit	^g  make-syntax-transformer	_^ 	`^ 	ag  errno-if-exception	bg  macro	cg  $sc-dispatch	dc 	ec 	fg  any	gff 	hg  
-syntax-object	ig  top	ji 	kg  ribcage	lg  dummy	mg  expr	nlm 	og  m-V3FVIlkbSl1Gw7szbH2pbj-3674	poi 	qpj 	rf  l-V3FVIlkbSl1Gw7szbH2pbj-3679	sf  l-V3FVIlkbSl1Gw7szbH2pbj-3680	trs 	uknqt 	vk 	wg  x	xw 	yp 	zf  l-V3FVIlkbSl1Gw7szbH2pbj-3676	{z 	|kxy{ 	}juv| 	~g  hygiene	~  hK}  g  quote h}  g  system-error h}    g  lambda h}  g  args h}  g  system-error-errno h}        g  syntax-violation     f  -source expression failed to match any pattern g  integer? g  vhash-assoc g  
+syntax-object	ig  top	ji 	kg  ribcage	lg  dummy	mg  expr	nlm 	og  m-cL@SLmETjwqZgirBySRP$c-3674	poi 	qpj 	rf  l-cL@SLmETjwqZgirBySRP$c-3679	sf  l-cL@SLmETjwqZgirBySRP$c-3680	trs 	uknqt 	vk 	wg  x	xw 	yp 	zf  l-cL@SLmETjwqZgirBySRP$c-3676	{z 	|kxy{ 	}juv| 	~g  hygiene	~  hK}  g  quote h}  g  system-error h}    g  lambda h}  g  args h}  g  system-error-errno h}        g  syntax-violation     f  -source expression failed to match any pattern g  integer? g  vhash-assoc g  
 vhash-cons g  directory-stream? g  fold g  cons g  
 alist-cons g  
 vlist-null g  basename g  error 
